==> cube-manager-3.1.0-20140606.152259-63-sources.jar: org/gcube/data/analysis/tabulardata/cube/time/QuarterCodelistCreator.java <==
package org.gcube.data.analysis.tabulardata.cube.time;

import java.util.Arrays;
import java.util.List;

import javax.inject.Inject;

import org.gcube.data.analysis.tabulardata.cube.data.DatabaseWrangler;
import org.gcube.data.analysis.tabulardata.cube.metadata.CubeMetadataWrangler;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.factories.AttributeColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.CodeColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.IdColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.IdColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.IntegerType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ImmutableLocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.table.TimePeriodTypeMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.type.TimeCodelistTableType;
import org.gcube.data.analysis.tabulardata.model.time.PeriodType;

import com.google.common.collect.Lists;

public class QuarterCodelistCreator implements TimeCodelistCreator {

	@Inject
	DatabaseWrangler dbWrangler;

	@Inject
	CubeMetadataWrangler cmWrangler;

	@Override
	public Table createTable() {
		Table codelist = createTableMeta();

		String tableName = createTableOnDBWithColumns(codelist.getColumns());
		codelist.setName(tableName);

		return cmWrangler.save(codelist, false);
	}

	private Table createTableMeta() {
		List<Column> columns = Lists.newArrayList(IdColumnFactory.create(), createCodeColumn(), createQuarterColumn(), createYearColumn(), createDecadeColumn());
		Table dayCodelist = new Table(new TimeCodelistTableType());
		dayCodelist.setColumns(columns);
		dayCodelist.setMetadata(new TimePeriodTypeMetadata(getManagedPeriodType()));
		return dayCodelist;
	}

	private String createTableOnDBWithColumns(List<Column> columns) {
		String tableName = dbWrangler.createTable();
		for (Column column : columns) {
			if (column.getColumnType() instanceof IdColumnType)
				continue;
			dbWrangler.addColumn(tableName, column.getName(), column.getDataType());
			dbWrangler.setNullable(tableName, column.getName(), false);
			if (column.getColumnType() instanceof CodeColumnType)
				dbWrangler.createUniqueIndex(tableName, column.getName());
		}
		dbWrangler.createInsertUpdateTriggerOnTable("update_time_dimension_" + tableName, tableName,
				"update_gregorian_quarter_dimension");
		return tableName;
	}

	private Column createCodeColumn() {
		Column codeColumn = new CodeColumnFactory().createDefault();
		codeColumn.setName("quarter_code");
		codeColumn.setDataType(new TextType(8));
		codeColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("quarter code"))));
		return codeColumn;
	}

	private Column createQuarterColumn() {
		Column quarterColumn = new AttributeColumnFactory().create(new IntegerType());
		quarterColumn.setName("quarter_of_year");
		quarterColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("quarter of year"))));
		return quarterColumn;
	}

	private Column createYearColumn() {
		Column yearColumn = new AttributeColumnFactory().create(new IntegerType());
		yearColumn.setName("year");
		yearColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("year"))));
		return yearColumn;
	}

	private Column createDecadeColumn() {
		Column resultColumn = new AttributeColumnFactory().create(new IntegerType());
		resultColumn.setName("decade");
		resultColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("decade"))));
		return resultColumn;
	}

	@Override
	public PeriodType getManagedPeriodType() {
		return PeriodType.QUARTER;
	}

}

==> cube-manager-3.2.0-20140702.151730-8-sources.jar: org/gcube/data/analysis/tabulardata/cube/time/QuarterCodelistCreator.java <==
package org.gcube.data.analysis.tabulardata.cube.time;

import java.util.Arrays;
import java.util.List;

import javax.inject.Inject;

import org.gcube.data.analysis.tabulardata.cube.data.DatabaseWrangler;
import org.gcube.data.analysis.tabulardata.cube.metadata.CubeMetadataWrangler;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.factories.AnnotationColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.CodeColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.factories.IdColumnFactory;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.IdColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.IntegerType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ImmutableLocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.LocalizedText;
import org.gcube.data.analysis.tabulardata.model.metadata.common.NamesMetadata;
import org.gcube.data.analysis.tabulardata.model.metadata.table.TimePeriodTypeMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.model.table.type.TimeCodelistTableType;
import org.gcube.data.analysis.tabulardata.model.time.PeriodType;

import com.google.common.collect.Lists;

public class QuarterCodelistCreator implements TimeCodelistCreator {

	@Inject
	DatabaseWrangler dbWrangler;

	@Inject
	CubeMetadataWrangler cmWrangler;

	@Override
	public Table createTable() {
		Table codelist = createTableMeta();

		String tableName = createTableOnDBWithColumns(codelist.getColumns());
		codelist.setName(tableName);

		return cmWrangler.save(codelist, false);
	}

	private Table createTableMeta() {
		List<Column> columns = Lists.newArrayList(IdColumnFactory.create(), createCodeColumn(), createQuarterColumn(), createYearColumn(), createDecadeColumn());
		Table dayCodelist = new Table(new TimeCodelistTableType());
		dayCodelist.setColumns(columns);
		dayCodelist.setMetadata(new TimePeriodTypeMetadata(getManagedPeriodType()));
		return dayCodelist;
	}

	private String createTableOnDBWithColumns(List<Column> columns) {
		String tableName = dbWrangler.createTable();
		for (Column column : columns) {
			if (column.getColumnType() instanceof IdColumnType)
				continue;
			dbWrangler.addColumn(tableName, column.getName(), column.getDataType());
			dbWrangler.setNullable(tableName, column.getName(), false);
			if (column.getColumnType() instanceof CodeColumnType)
				dbWrangler.createUniqueIndex(tableName, column.getName());
		}
		dbWrangler.createInsertUpdateTriggerOnTable("update_time_dimension_" + tableName, tableName,
				"update_gregorian_quarter_dimension");
		return tableName;
	}

	private Column createCodeColumn() {
		Column codeColumn = new CodeColumnFactory().createDefault();
		codeColumn.setName("quarter_code");
		codeColumn.setDataType(new TextType(8));
		codeColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("quarter code"))));
		return codeColumn;
	}

	private Column createQuarterColumn() {
		Column quarterColumn = new AnnotationColumnFactory().create(new IntegerType());
		quarterColumn.setName("quarter_of_year");
		quarterColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("quarter of year"))));
		return quarterColumn;
	}

	private Column createYearColumn() {
		Column yearColumn = new AnnotationColumnFactory().create(new IntegerType());
		yearColumn.setName("year");
		yearColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("year"))));
		return yearColumn;
	}

	private Column createDecadeColumn() {
		Column resultColumn = new AnnotationColumnFactory().create(new IntegerType());
		resultColumn.setName("decade");
		resultColumn.setMetadata(new NamesMetadata(Arrays.asList((LocalizedText)new ImmutableLocalizedText("decade"))));
		return resultColumn;
	}

	@Override
	public PeriodType getManagedPeriodType() {
		return PeriodType.QUARTER;
	}

}
